require 'fileutils'
require 'spinna/history'
require 'spinna/config'
require 'spinna/picker'
require 'spinna/music_library'

module Spinna
  # The client takes care of initializing the application by reading
  # the configuration and the history. It exposes the various commands
  # that spinna can do.
  class Client
    attr_accessor :library
    attr_accessor :config
    attr_accessor :history

    # Boots the application.
    def initialize
      init_configuration
      init_history
      init_library
    end

    # Get a certain number of random albums from the music collection.
    def get(opts = {})
      number_of_picks = opts[:number_of_picks] || config.number_of_picks
      pattern = opts[:pattern] || nil
      Picker.new(config, history, library).pick(number_of_picks, pattern)
    end

    private

    def init_configuration
      @config = Config.new
    end

    def init_history
      @history = Spinna::History.new(config)
    end

    def init_library
      @library = Spinna::MusicLibrary.new(config, history)
    end
  end
end
