module Spinna
  # This class encapsulates the access to the music library.
  class MusicLibrary
    def initialize(config, history)
      @config = config
      @history = history
    end

    # Returns the albums that are pickable. An album is pickable
    # if it isn’t present in the history log. If a pattern is given,
    # then only the albums that match the pattern will be returned.
    def pickable_albums(pattern = nil)
      return available_albums unless pattern
      available_albums.select! { |a| a =~ Regexp.new(pattern)}
    end

    private

    attr_reader :config
    attr_reader :history

    def albums
      Dir.entries(config.source_dir).reject! { |i| i =~ /\A\./ }
    end

    # Returns the list of previously selected albums.
    def previously_selected_albums
      history.log
    end

    # Returns only the albums that are available for selection.
    def available_albums
      albums - previously_selected_albums
    end
  end
end
