module Spinna
  # The picker is responsible for reading the media library, selecting
  # albums from it and updating the history log. Basically, it does the
  # grunt work.
  class Picker
    def initialize(config, history, library)
      @config = config
      @history = history
      @library = library
    end

    # Picks the requested number of picks from the available albums.
    def pick(number_of_picks, pattern = nil)
      picks = pick_albums(number_of_picks, pattern)
      copy_picks(picks)
      update_history(picks)
      picks
    end

    private

    attr_accessor :config
    attr_accessor :history
    attr_accessor :library

    def pick_albums(number_of_picks, pattern = nil)
      albums = library.pickable_albums(pattern)
      return albums if number_of_picks >= albums.size
      choose_random_picks(number_of_picks, albums)
    end

    # Does the actual picking of random albums.
    def choose_random_picks(number_of_picks, albums)
      return albums if albums.size < number_of_picks
      albums.sample(number_of_picks)
    end

    # Copies the picks to the current working directory.
    def copy_picks(picks)
      picks.each do |pick|
        puts "Copying #{pick}..."
        FileUtils.cp_r("#{config.source_dir}/#{pick}", Dir.pwd)
      end
    end

    # Updates the history.
    def update_history(picks)
      picks.each { |pick| history.append(pick) }
      history.save
    end
  end
end
